from setuptools import setup

setup(
    name='utopia_pipeline_tools',
    version='0.3.24',    
    description='A Python package for managing data in the ifcbUTOPIA project',
    url='https://github.com/ifcb-utopia/data_pipeline',
    author='Claire Berschauer',
    author_email='ckb22@uw.edu',
    license='GPLv3',  
    install_requires=['numpy', 
                      'jupyter',
                      'ipykernel',
                      'numpy>=1.2',
                      'pandas>=1.4',
                      'scikit-learn>=1.2',
                      'matplotlib>=3.5',
                      'imageio',
                      'tensorflow==2.13.1',
                      'pip',
                      'tqdm',
                      'pylint',
                      'modAL',
                      'azure-storage-blob',
                      'azure-mgmt-compute',
                      'azure-identity',
                      'azure-mgmt-storage',
                      'opencv-python',
                      'pymssql>=2.2',
                      'plotly',
                      'umap-learn',
                      'marimo',
                      'seaborn',
                      'IPython',
                      'streamlit==1.29',
                      'keras'                 
                      ],  ## all the dependencies

    classifiers=[
        'Development Status :: 1 - Planning',
        'Topic :: Scientific/Engineering :: Oceanography',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',  
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Programming Language :: Python :: 3.10',
    ],  
)